==> familia_0.1.tar.gz: familia/src/file/gno/gno.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_GNO_H
#define _FILE_GNO_H

#include <iostream>
#include <istream>
#include <string>
#include <vector>
#include <stack>
#include <glibmm/ustring.h> //Glib::ustring
#include <libxml++/libxml++.h>
#include <sigc++/sigc++.h>

#include "../file.h"

using namespace std;

namespace file {

enum CollectionType {
  individual,
  family,

  not_set
};

enum IndividualState {
  unknown,
  individualName,
  nameDisplay,
  nameFirst,
  nameMiddle,
  nameLast,
  pictures,
  contacts,
  position,
  gender,
  isDead,
  birth,
  birthDate,
  birthPlace,
  birthBaptism,
  birthBaptismDate,
  birthBaptismPlace,
  birthBaptismOfficiator,
  birthBaptismGodfather,
  birthBaptismGodmother,
  comment,
  educations,
  hyperlink,
  child_no
};

enum FamilyState {
  //  position,
  positionTop,
  positionTopLeft,
  positionTopRight,
  positionBottom,
  positionBottomLeft,
  positionBottomRight,
  familyLine,
  relation,
  children,
  unions,
};

typedef Glib::ustring _String;

/**
 * Gno file parser
 */
class Gno : public file::File, public xmlpp::SaxParser {
public:
  typedef File _Myt;
public:
  Gno(const _String filename);
  virtual ~Gno();

protected:
  virtual void on_start_element(const _String& name,
                                const AttributeList& properties);
  virtual void on_end_element (const Glib::ustring& name);
  virtual void on_characters (const Glib::ustring& characters);

private:
  CollectionType currentCollection;

  IndividualState individualState;
  FamilyState familyState;
  _Individual current_individual;
  _Family current_family;
};


int parseFamilyIdentifier(_String identifier);
int parseIndividualIdentifier(_String identifier);
gender_type parseIndividualGender(_String str);
bool parseIndividualDeadState(_String str);

}
#endif

==> familia_0.1.2.tar.gz: familia/src/file/gno/gno.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _FILE_GNO_H
#define _FILE_GNO_H

#include <iostream>
#include <istream>
#include <string>
#include <vector>
#include <stack>
#include <glibmm/ustring.h> //Glib::ustring
#include <libxml++/libxml++.h>
#include <sigc++/sigc++.h>

#include "../file.h"

using namespace std;

namespace file {

enum CollectionType {
  collectionTypeUnknown,
  individual,
  family,

  not_set
};

enum IndividualState {
  individualStateUnknown,
  individualName,
  nameDisplay,
  nameFirst,
  nameMiddle,
  nameLast,
  pictures,
  contacts,
  position,
  gender,
  isDead,
  birth,
  birthDate,
  birthPlace,
  birthBaptism,
  birthBaptismDate,
  birthBaptismPlace,
  birthBaptismOfficiator,
  birthBaptismGodfather,
  birthBaptismGodmother,
  comment,
  educations,
  hyperlink,
  child_no
};

enum FamilyState {
  familyStateUnknown,
  //  position,
  positionTop,
  positionTopLeft,
  positionTopRight,
  positionBottom,
  positionBottomLeft,
  positionBottomRight,
  familyLine,
  relation,
  children,
  unions,
};

typedef Glib::ustring String;

/**
 * Gno file parser
 */
class Gno : public xmlpp::SaxParser
{
public:
  typedef File _Myt;
public:
  Gno(File *file);
  Gno(const String filename);
  virtual ~Gno();

protected:
  virtual void on_start_element(const String& name,
                                const AttributeList& attributes);
  virtual void on_individual_start_element(const String& name,
					   const AttributeList& attributes);
  virtual void on_family_start_element(const String& name,
				       const AttributeList& attributes);
  virtual void on_end_element(const Glib::ustring& name);
  virtual void on_characters(const Glib::ustring& characters);
  virtual void on_individual_characters(const Glib::ustring& characters);
  virtual void on_family_characters(const Glib::ustring& characters);

private:
  File * m_ptrFile;
  bool expect_characters;
  CollectionType currentCollection;

  IndividualState individualState;
  FamilyState familyState;
};


int parseFamilyIdentifier(String identifier);
int parseIndividualIdentifier(String identifier);
gender_type parseIndividualGender(String str);
bool parseIndividualDeadState(String str);

}
#endif
